@@ -19,8 +19,6 @@
 # Everything you need to know (Google API Calendar v3): http://goo.gl/HfTGQ #
 #                                                                           #
 #############################################################################
-from __future__ import absolute_import, print_function
-
 import os
 import signal
 import sys
@@ -31,10 +29,9 @@ from gcalcli.argparsers import get_argument_parser, handle_unparsed
 from gcalcli.exceptions import GcalcliError
 from gcalcli.gcal import GoogleCalendarInterface
 from gcalcli.printer import Printer, valid_color_name
-from gcalcli.utils import _u
 from gcalcli.validators import (
-        PARSABLE_DATE, REMINDER, STR_ALLOW_EMPTY, STR_NOT_EMPTY, STR_TO_INT,
-        get_input
+        PARSABLE_DATE, REMINDER, STR_ALLOW_EMPTY, STR_NOT_EMPTY,
+        PARSABLE_DURATION, get_input
 )
 
 CalName = namedtuple('CalName', ['name', 'color'])
@@ -71,8 +68,8 @@ def run_add_prompt(parsed_args, printer):
         if parsed_args.allday:
             prompt = 'Duration (days): '
         else:
-            prompt = 'Duration (minutes): '
-        parsed_args.duration = get_input(printer, prompt, STR_TO_INT)
+            prompt = 'Duration (human readable): '
+        parsed_args.duration = get_input(printer, prompt, PARSABLE_DURATION)
     if parsed_args.description is None:
         parsed_args.description = get_input(
             printer, 'Description: ', STR_ALLOW_EMPTY)
@@ -160,6 +157,12 @@ def main():
                     start=parsed_args.start,
                     end=parsed_args.end)
 
+        elif parsed_args.command == 'conflicts':
+            gcal.ConflictsQuery(
+                    search_text=parsed_args.text,
+                    start=parsed_args.start,
+                    end=parsed_args.end)
+
         elif parsed_args.command == 'calw':
             gcal.CalQuery(
                     parsed_args.command, count=parsed_args.weeks,
@@ -176,7 +179,7 @@ def main():
 
             # allow unicode strings for input
             gcal.QuickAddEvent(
-                    _u(parsed_args.text), reminders=parsed_args.reminders
+                    parsed_args.text, reminders=parsed_args.reminders
             )
 
         elif parsed_args.command == 'add':
